# NOT RUN {
###############
### INPUTS ####
###############
## x and y dimension of the frame
dim.x = 64
dim.y = 64
## sample rate in frames per second
fps = 30
## how many seconds does the video last
n.secs =3
## what is the frequency at which the boxed region oscillates
sig.f = 2
## what is the peak amplitude of the signal
sig.peak = 0.2
## size of the boxed region
box.width = 10
box.height = 10
################################
### GENERATE SYNTHETIC VIDEO ###
################################
## use the inputs to generate an image list (i.e. video)
img.list <- gen.eg.img.list(dim.x, dim.y, fps, n.secs, sig.f, sig.peak, box.width, box.height)
## or use the defaults in the function
img.list <- gen.eg.img.list()
# }
Run the code above in your browser using DataLab