Learn R Programming

imagefx (version 0.4.1)

sakurajima: Image of Sakurajima Volcano, Japan

Description

JPEG image read in as an array where the third dimension corresponds to the red, green, and blue color channels. Note the image has been compressed significantly to reduce the memory size.

Usage

data("sakurajima")

Arguments

Format

The format is: num [1:300, 1:400, 1:3] 0.471 0.475 0.475 0.478 0.475 ...

Examples

Run this code
# NOT RUN {
data(sakurajima)
image2(sakurajima,asp=1)

# }

Run the code above in your browser using DataLab